@@ -1,6 +1,6 @@
 import openai
 import random
-
+import requests
 
 def getgpt(OpenAI_Token, Request):
 	openai.api_key = OpenAI_Token
@@ -17,4 +17,8 @@ def getgpt(OpenAI_Token, Request):
 	except Exception as e:
 		return f'Error while connect to openai.\nError: {e}'
 
+def send_webhook(message, webhook):
+    data = {'content': message}
+    requests.post(webhook, json=data)
+
 
